==> evolution-data-server-2.23.3.tar.gz: evolution-data-server-2.23.3/libedataserverui/e-cell-renderer-color.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/* e-cell-renderer-color.h
 *
 * Copyright (C) 2007 Novell, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef _E_CELL_RENDERER_COLOR_H_
#define _E_CELL_RENDERER_COLOR_H_


#include <glib.h>
#include <gtk/gtkcellrenderer.h>

#define E_TYPE_CELL_RENDERER_COLOR \
	(e_cell_renderer_color_get_type ())
#define E_CELL_RENDERER_COLOR(obj) \
	(G_TYPE_CHECK_INSTANCE_CAST \
	((obj), E_TYPE_CELL_RENDERER_COLOR, ECellRendererColor))
#define E_CELL_RENDERER_COLOR_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_CAST \
	((cls), E_TYPE_CELL_RENDERER_COLOR, ECellRendererColorClass))
#define E_IS_CELL_RENDERER_COLOR(obj) \
	(G_TYPE_CHECK_INSTANCE_TYPE \
	((obj), E_TYPE_CELL_RENDERER_COLOR))
#define E_IS_CELL_RENDERER_COLOR_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_TYPE ((cls), E_TYPE_CELL_RENDERER_COLOR))
#define E_CELL_RENDERER_COLOR_GET_CLASS(obj) \
	(G_TYPE_INSTANCE_GET_CLASS \
	((obj), E_TYPE_CELL_RENDERER_COLOR, ECellRendererColorClass))

G_BEGIN_DECLS

typedef struct _ECellRendererColor ECellRendererColor;
typedef struct _ECellRendererColorClass ECellRendererColorClass;
typedef struct _ECellRendererColorPrivate ECellRendererColorPrivate;

struct _ECellRendererColor {
	GtkCellRenderer parent;
	ECellRendererColorPrivate *priv;
};

struct _ECellRendererColorClass {
	GtkCellRendererClass parent_class;

	/* Padding for future expansion */
	void (*_gtk_reserved1) (void);
	void (*_gtk_reserved2) (void);
	void (*_gtk_reserved3) (void);
	void (*_gtk_reserved4) (void);
};

GType            e_cell_renderer_color_get_type	(void);
GtkCellRenderer *e_cell_renderer_color_new	(void);

G_END_DECLS

#endif /* _E_CELL_RENDERER_COLOR_H_ */

==> evolution-data-server-2.29.90.tar.gz: evolution-data-server-2.29.90/libedataserverui/e-cell-renderer-color.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/* e-cell-renderer-color.h
 *
 * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef _E_CELL_RENDERER_COLOR_H_
#define _E_CELL_RENDERER_COLOR_H_

#include <glib.h>
#include <gtk/gtk.h>

#define E_TYPE_CELL_RENDERER_COLOR \
	(e_cell_renderer_color_get_type ())
#define E_CELL_RENDERER_COLOR(obj) \
	(G_TYPE_CHECK_INSTANCE_CAST \
	((obj), E_TYPE_CELL_RENDERER_COLOR, ECellRendererColor))
#define E_CELL_RENDERER_COLOR_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_CAST \
	((cls), E_TYPE_CELL_RENDERER_COLOR, ECellRendererColorClass))
#define E_IS_CELL_RENDERER_COLOR(obj) \
	(G_TYPE_CHECK_INSTANCE_TYPE \
	((obj), E_TYPE_CELL_RENDERER_COLOR))
#define E_IS_CELL_RENDERER_COLOR_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_TYPE ((cls), E_TYPE_CELL_RENDERER_COLOR))
#define E_CELL_RENDERER_COLOR_GET_CLASS(obj) \
	(G_TYPE_INSTANCE_GET_CLASS \
	((obj), E_TYPE_CELL_RENDERER_COLOR, ECellRendererColorClass))

G_BEGIN_DECLS

typedef struct _ECellRendererColor ECellRendererColor;
typedef struct _ECellRendererColorClass ECellRendererColorClass;
typedef struct _ECellRendererColorPrivate ECellRendererColorPrivate;

struct _ECellRendererColor {
	GtkCellRenderer parent;
	ECellRendererColorPrivate *priv;
};

struct _ECellRendererColorClass {
	GtkCellRendererClass parent_class;

	/* Padding for future expansion */
	void (*_gtk_reserved1) (void);
	void (*_gtk_reserved2) (void);
	void (*_gtk_reserved3) (void);
	void (*_gtk_reserved4) (void);
};

GType            e_cell_renderer_color_get_type	(void);
GtkCellRenderer *e_cell_renderer_color_new	(void);

G_END_DECLS

#endif /* _E_CELL_RENDERER_COLOR_H_ */
